Documentation
¶
Index ¶
Constants ¶
const ( LockfileName = "wpm.lock" CurrentVersion = 1 )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LockPackage ¶
type LockPackage struct {
Version string `json:"version"`
Resolved string `json:"resolved"`
Digest string `json:"digest"`
Type types.PackageType `json:"type"`
Bin *types.Bin `json:"bin,omitempty"`
Dependencies *types.Dependencies `json:"dependencies,omitempty"`
}
LockPackage represents a specific version of a package locked in the lockfile.
type Lockfile ¶
type Lockfile struct {
LockfileVersion int `json:"lockfileVersion"`
Packages map[string]LockPackage `json:"packages"`
Indentation string `json:"-"`
}
Lockfile represents the state of the dependency tree. Since wpm does not support nesting, this is a flat map of package names to their locked details.
func (*Lockfile) SetIndentation ¶
SetIndentation sets the indentation style for the lockfile when written to disk.
Click to show internal directories.
Click to hide internal directories.